@@ -7,14 +7,11 @@
 */
 
 #include "framemanager.h"
-#include "actionmanager.h"
 #include "akregator_debug.h"
 #include "akregatorconfig.h"
 #include "frame.h"
 #include "openurlrequest.h"
 #include <KConfigGroup>
-#include <KIO/JobUiDelegate>
-#include <KIO/OpenUrlJob>
 #include <KMacroExpander>
 #include <KProcess>
 #include <KShell>
